@@ -107,6 +107,7 @@ class Configuration(client.Configuration):
         *,
         grant_type="authorization_code",
         client_id="PythonClient",
+        client_secret="",
         username="",
         offline=False,
         host=None,
@@ -115,7 +116,7 @@ class Configuration(client.Configuration):
 
         self.grant_type = grant_type
         self.client_id = client_id
-        self.client_secret = ""
+        self.client_secret = client_secret
         self.username = username
         self.password = ""
         self.token = {}
@@ -204,6 +205,7 @@ class Configuration(client.Configuration):
         token = self.session.fetch_token(
             token_url=self.token_endpoint,
             client_id=self.client_id,
+            client_secret=self.client_secret,
             username=username,
             password=password,
             verify=self.verify_ssl,
@@ -266,6 +268,7 @@ class Configuration(client.Configuration):
             token_url=self.token_endpoint,
             authorization_response=authorization_response.pop(),
             client_id=self.client_id,
+            client_secret=self.client_secret,
             verify=self.verify_ssl,
         )
         self._check_returned_token(token)
