@@ -59,7 +59,6 @@ from alchemite_apiclient.model.dataset import Dataset
 from alchemite_apiclient.model.dataset1 import Dataset1
 from alchemite_apiclient.model.dataset_calculated_columns import DatasetCalculatedColumns
 from alchemite_apiclient.model.dataset_chunk import DatasetChunk
-from alchemite_apiclient.model.dataset_extensions import DatasetExtensions
 from alchemite_apiclient.model.dataset_favourite_query import DatasetFavouriteQuery
 from alchemite_apiclient.model.dataset_or_data import DatasetOrData
 from alchemite_apiclient.model.dataset_patch import DatasetPatch
@@ -89,6 +88,9 @@ from alchemite_apiclient.model.dimensionality_reduction_response import Dimensio
 from alchemite_apiclient.model.empty_categorical_column import EmptyCategoricalColumn
 from alchemite_apiclient.model.empty_continuous_column import EmptyContinuousColumn
 from alchemite_apiclient.model.error import Error
+from alchemite_apiclient.model.extension import Extension
+from alchemite_apiclient.model.extension_infocol import ExtensionInfocol
+from alchemite_apiclient.model.extension_infocol_arguments import ExtensionInfocolArguments
 from alchemite_apiclient.model.favourite_dataset import FavouriteDataset
 from alchemite_apiclient.model.favourite_job import FavouriteJob
 from alchemite_apiclient.model.favourite_patch import FavouritePatch
@@ -233,6 +235,7 @@ from alchemite_apiclient.model.part_dependent_columns import PartDependentColumn
 from alchemite_apiclient.model.part_get_optimize import PartGetOptimize
 from alchemite_apiclient.model.part_get_optimize_consistent import PartGetOptimizeConsistent
 from alchemite_apiclient.model.part_get_optimize_done_result_array import PartGetOptimizeDoneResultArray
+from alchemite_apiclient.model.part_get_optimize_sharing import PartGetOptimizeSharing
 from alchemite_apiclient.model.part_get_suggest_additional import PartGetSuggestAdditional
 from alchemite_apiclient.model.part_get_suggest_historic import PartGetSuggestHistoric
 from alchemite_apiclient.model.part_get_suggest_initial import PartGetSuggestInitial
