@@ -2,7 +2,7 @@ import csv
 from io import StringIO
 
 import alchemite_apiclient as client
-from alchemite_apiclient.extensions import Configuration
+from alchemite_apiclient.extensions import Configuration, await_uploaded
 
 configuration = Configuration()
 api_default = client.DefaultApi(client.ApiClient(configuration))
@@ -58,8 +58,8 @@ dataset = {
 dataset_id = api_datasets.datasets_post(dataset=dataset)
 print("Uploaded dataset:", dataset_id)
 
-# Get the metadata about this dataset
-dataset_metadata = api_datasets.datasets_id_get(dataset_id)
+# Wait for dataset to be processed and get the metadata about this dataset
+dataset_metadata = await_uploaded(lambda: api_datasets.datasets_id_get(dataset_id))
 print("-------------Dataset Metadata-------------")
 print(dataset_metadata)
 
