@@ -1,4 +1,3 @@
-from __future__ import print_function
 import json
 
 import alchemite_apiclient as client
@@ -16,7 +15,9 @@ suggest_initial_args_path = "suggest_initial_args.json"
 api_response = api_default.version_get()
 print("------ API & Python Client Versions ------")
 print(api_response)
-print(f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})")
+print(
+    f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})"
+)
 print("------------------------------------------")
 
 
@@ -30,11 +31,10 @@ with open(suggest_initial_args_path, encoding="UTF-8") as f:
     suggest_initial_args = json.load(f)
 
 # Send suggest_initial request
-suggest_initial_job_id = api_default.suggest_initial_post(
-    **suggest_initial_args
-)
+suggest_initial_job_id = api_default.suggest_initial_post(**suggest_initial_args)
 print("suggest_initial job ID:", suggest_initial_job_id)
 
+
 # Wait until the suggest_initial job has finished
 def get_suggest_initial_job_metadata():
     return api_default.suggest_initial_job_id_get(suggest_initial_job_id)
